==> haskell-store-0.4.3.2-134-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-store.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: store
version: 0.4.3.2
id: store-0.4.3.2-AgL5KzY5mgU69biceDGe3L
key: store-0.4.3.2-AgL5KzY5mgU69biceDGe3L
license: MIT
copyright: 2016 FP Complete
maintainer: Michael Sloan <sloan@fpcomplete.com>
homepage: https://github.com/fpco/store#readme
synopsis: Fast binary serialization
category: Serialization, Data
abi: dccdea01d7bfe8c59caddb27b8dadb65
exposed: True
exposed-modules:
    Data.Store Data.Store.Internal Data.Store.Streaming
    Data.Store.Streaming.Internal Data.Store.TH Data.Store.TH.Internal
    Data.Store.TypeHash Data.Store.TypeHash.Internal Data.Store.Version
    System.IO.ByteBuffer
hidden-modules: Data.Store.Impl
import-dirs: /usr/lib/ghc-8.4.3/site-local/store-0.4.3.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/store-0.4.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/store-0.4.3.2
hs-libraries: HSstore-0.4.3.2-AgL5KzY5mgU69biceDGe3L
depends:
    base-4.11.1.0 store-core-0.4.4-1LM4ohAAnnyFHJEmPncRK6
    th-utilities-0.2.0.1-Df7FKaU1jfuAJ8mBJ9IVyk
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc
    th-reify-many-0.1.8-LtTyEtBGK5I3tMqmzVk4c8 array-0.5.2.0
    base-orphans-0.8-4huH01MmiV449ptUKInvC8
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    bytestring-0.10.8.2 conduit-1.3.0.3-JvPBE4EhGj9IqkHmyEaMOO
    containers-0.5.11.0 cryptohash-0.11.9-HjLcGiIxEFW8kOSZVaJ9pE
    deepseq-1.4.3.0 directory-1.3.1.5 filepath-1.4.2 ghc-prim-0.5.2.0
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    hspec-2.5.5-EBrhXnEvtIxLStRjmukT1L
    hspec-smallcheck-0.5.2-AxnP77Hl9mz1RHTVm6EbG3 integer-gmp-1.0.2.0
    lifted-base-0.2.3.12-Fa7wI9LgVyV52yh4Mgi8Zu
    monad-control-1.0.2.3-I3eeoimEMDTINIqXKgCbLk
    mono-traversable-1.0.9.0-LcbzVEtjdbL4nW0GIOikJZ
    resourcet-1.2.1-LmgqSpZgtYc1CYRXUZoy4I
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    smallcheck-1.1.5-3f5qiJxrEExLmWHgkqVfWS
    syb-0.7-2jW43lwzJV5e7EQvU8PxV template-haskell-2.13.0.0
    text-1.2.3.0 th-lift-0.7.10-88ozaMeoe8eDZSlyIjheFa
    th-lift-instances-0.1.11-5QBYPv19Jm62L2a70pIjbc
    th-orphans-0.13.6-93sbM5rdqaKJ6VAc2fxTbO time-1.8.0.2
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    void-0.7.2-JAsenjnj1DBHDal2sW0JoW free-5.1-HT7N17Zwnuw79GRgcsQMzL
    network-2.7.0.2-1OJnZsn219R1IXngT025LR
    streaming-commons-0.2.1.0-2y3UhC0AAPrCaYwZozhK9I
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    contravariant-1.5-HWHOmzUIRDZBjbL8Fw1HTI
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             store-core-0.4.4-1LM4ohAAnnyFHJEmPncRK6=ecb6b3b45cffc0af6d2bce168037dbc0
             th-utilities-0.2.0.1-Df7FKaU1jfuAJ8mBJ9IVyk=38c403040ba7a830ae93d7320d87d9b6
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             th-reify-many-0.1.8-LtTyEtBGK5I3tMqmzVk4c8=16cc9fccc2db1abb8c55d937cd6178ff
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-orphans-0.8-4huH01MmiV449ptUKInvC8=e9fa092af04cd58ebcb8cdf33f10dac9
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             conduit-1.3.0.3-JvPBE4EhGj9IqkHmyEaMOO=edcb68965d1c4f937af777b49e45f52f
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             cryptohash-0.11.9-HjLcGiIxEFW8kOSZVaJ9pE=60774213ec4b880ec762bba3862dd227
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             hspec-2.5.5-EBrhXnEvtIxLStRjmukT1L=eb57a05d4e8f4e54695680abf9dd1c16
             hspec-smallcheck-0.5.2-AxnP77Hl9mz1RHTVm6EbG3=38e6a39054c3b0b7076f4de792f00f20
             integer-gmp-1.0.2.0=9ea484dc1eeb054803bb4cf8d65c934d
             lifted-base-0.2.3.12-Fa7wI9LgVyV52yh4Mgi8Zu=c1af0fff2fd5bc4c8d013de762962125
             monad-control-1.0.2.3-I3eeoimEMDTINIqXKgCbLk=7b91fe2931b6520a589ebb0da769a2de
             mono-traversable-1.0.9.0-LcbzVEtjdbL4nW0GIOikJZ=ada8bca8e6a1d1a27bd476ae1fef6c0f
             resourcet-1.2.1-LmgqSpZgtYc1CYRXUZoy4I=3fbb0f35b28cf76949df3af0a83627ff
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             smallcheck-1.1.5-3f5qiJxrEExLmWHgkqVfWS=aec4190e63046da29e6cea1cb38a365c
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=867165047495b4e6f144c8b9b108f918
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             th-lift-0.7.10-88ozaMeoe8eDZSlyIjheFa=60d068a969a5d731636a40e25634c1aa
             th-lift-instances-0.1.11-5QBYPv19Jm62L2a70pIjbc=a9ca9df4c71028951428e3523909bf7f
             th-orphans-0.13.6-93sbM5rdqaKJ6VAc2fxTbO=08322e2607a4e228d1d47389937993aa
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             void-0.7.2-JAsenjnj1DBHDal2sW0JoW=d1de746fbfbe471314dbcb65b5e13ec4
             free-5.1-HT7N17Zwnuw79GRgcsQMzL=61d01a0a1f0be0653955cf84b7f24de1
             network-2.7.0.2-1OJnZsn219R1IXngT025LR=3133613495d02f305adaa7a6ab03f465
             streaming-commons-0.2.1.0-2y3UhC0AAPrCaYwZozhK9I=d02eb8f4075c36aa63e714831eccd502
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             contravariant-1.5-HWHOmzUIRDZBjbL8Fw1HTI=d2f13618f92bbccf0540968a185d3c43
haddock-interfaces: /usr/share/doc/haskell-store/html/store.haddock
haddock-html: /usr/share/doc/haskell-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-store-0.4.3.2-135-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-store.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: store
version: 0.4.3.2
id: store-0.4.3.2-BdHPPHbGA5q2meHFN1c8Fe
key: store-0.4.3.2-BdHPPHbGA5q2meHFN1c8Fe
license: MIT
copyright: 2016 FP Complete
maintainer: Michael Sloan <sloan@fpcomplete.com>
homepage: https://github.com/fpco/store#readme
synopsis: Fast binary serialization
category: Serialization, Data
abi: 3d06f1b9d0dd8251461d1d31df5cc4d2
exposed: True
exposed-modules:
    Data.Store Data.Store.Internal Data.Store.Streaming
    Data.Store.Streaming.Internal Data.Store.TH Data.Store.TH.Internal
    Data.Store.TypeHash Data.Store.TypeHash.Internal Data.Store.Version
    System.IO.ByteBuffer
hidden-modules: Data.Store.Impl
import-dirs: /usr/lib/ghc-8.4.3/site-local/store-0.4.3.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/store-0.4.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/store-0.4.3.2
hs-libraries: HSstore-0.4.3.2-BdHPPHbGA5q2meHFN1c8Fe
depends:
    base-4.11.1.0 store-core-0.4.4-1LM4ohAAnnyFHJEmPncRK6
    th-utilities-0.2.0.1-Df7FKaU1jfuAJ8mBJ9IVyk
    primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc
    th-reify-many-0.1.8-LtTyEtBGK5I3tMqmzVk4c8 array-0.5.2.0
    base-orphans-0.8-4huH01MmiV449ptUKInvC8
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    bytestring-0.10.8.2 conduit-1.3.0.3-6xFp3IVlqKk1H8MPIHk8Vm
    containers-0.5.11.0 cryptohash-0.11.9-HjLcGiIxEFW8kOSZVaJ9pE
    deepseq-1.4.3.0 directory-1.3.1.5 filepath-1.4.2 ghc-prim-0.5.2.0
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    hspec-2.5.5-EBrhXnEvtIxLStRjmukT1L
    hspec-smallcheck-0.5.2-AxnP77Hl9mz1RHTVm6EbG3 integer-gmp-1.0.2.0
    lifted-base-0.2.3.12-Fa7wI9LgVyV52yh4Mgi8Zu
    monad-control-1.0.2.3-I3eeoimEMDTINIqXKgCbLk
    mono-traversable-1.0.9.0-3a1ENcmXRgy7zZJQ8bLMtp
    resourcet-1.2.1-LmgqSpZgtYc1CYRXUZoy4I
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    smallcheck-1.1.5-3f5qiJxrEExLmWHgkqVfWS
    syb-0.7-2jW43lwzJV5e7EQvU8PxV template-haskell-2.13.0.0
    text-1.2.3.0 th-lift-0.7.10-88ozaMeoe8eDZSlyIjheFa
    th-lift-instances-0.1.11-5QBYPv19Jm62L2a70pIjbc
    th-orphans-0.13.6-93sbM5rdqaKJ6VAc2fxTbO time-1.8.0.2
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    void-0.7.2-JAsenjnj1DBHDal2sW0JoW free-5.1-EwW4u6qzzP59BqdPPpEiVl
    network-2.7.0.2-1OJnZsn219R1IXngT025LR
    streaming-commons-0.2.1.0-2y3UhC0AAPrCaYwZozhK9I
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    contravariant-1.5-5VBqEYOPGpyDW8QIali4BA
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             store-core-0.4.4-1LM4ohAAnnyFHJEmPncRK6=ecb6b3b45cffc0af6d2bce168037dbc0
             th-utilities-0.2.0.1-Df7FKaU1jfuAJ8mBJ9IVyk=38c403040ba7a830ae93d7320d87d9b6
             primitive-0.6.4.0-39Pwmm1zkQX6bM7xFUT3Jc=0a8d9e3ca28de3a4ac62e5f0044fa23c
             th-reify-many-0.1.8-LtTyEtBGK5I3tMqmzVk4c8=16cc9fccc2db1abb8c55d937cd6178ff
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-orphans-0.8-4huH01MmiV449ptUKInvC8=e9fa092af04cd58ebcb8cdf33f10dac9
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             conduit-1.3.0.3-6xFp3IVlqKk1H8MPIHk8Vm=8fb4f8faceb9c4a09f79c43d892ca6f5
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             cryptohash-0.11.9-HjLcGiIxEFW8kOSZVaJ9pE=60774213ec4b880ec762bba3862dd227
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             hspec-2.5.5-EBrhXnEvtIxLStRjmukT1L=eb57a05d4e8f4e54695680abf9dd1c16
             hspec-smallcheck-0.5.2-AxnP77Hl9mz1RHTVm6EbG3=38e6a39054c3b0b7076f4de792f00f20
             integer-gmp-1.0.2.0=9ea484dc1eeb054803bb4cf8d65c934d
             lifted-base-0.2.3.12-Fa7wI9LgVyV52yh4Mgi8Zu=c1af0fff2fd5bc4c8d013de762962125
             monad-control-1.0.2.3-I3eeoimEMDTINIqXKgCbLk=7b91fe2931b6520a589ebb0da769a2de
             mono-traversable-1.0.9.0-3a1ENcmXRgy7zZJQ8bLMtp=07303bb0d9c9f4aa38a89905bbd3f749
             resourcet-1.2.1-LmgqSpZgtYc1CYRXUZoy4I=3fbb0f35b28cf76949df3af0a83627ff
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=42026212d0dad8beaed25fde58365be8
             smallcheck-1.1.5-3f5qiJxrEExLmWHgkqVfWS=aec4190e63046da29e6cea1cb38a365c
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=867165047495b4e6f144c8b9b108f918
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             th-lift-0.7.10-88ozaMeoe8eDZSlyIjheFa=60d068a969a5d731636a40e25634c1aa
             th-lift-instances-0.1.11-5QBYPv19Jm62L2a70pIjbc=a9ca9df4c71028951428e3523909bf7f
             th-orphans-0.13.6-93sbM5rdqaKJ6VAc2fxTbO=08322e2607a4e228d1d47389937993aa
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             void-0.7.2-JAsenjnj1DBHDal2sW0JoW=d1de746fbfbe471314dbcb65b5e13ec4
             free-5.1-EwW4u6qzzP59BqdPPpEiVl=c86139ee7b653ef1ffe3ec5d788f53c3
             network-2.7.0.2-1OJnZsn219R1IXngT025LR=3133613495d02f305adaa7a6ab03f465
             streaming-commons-0.2.1.0-2y3UhC0AAPrCaYwZozhK9I=d02eb8f4075c36aa63e714831eccd502
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             contravariant-1.5-5VBqEYOPGpyDW8QIali4BA=02e9ed60b8864056c6af15ff76a262ef
haddock-interfaces: /usr/share/doc/haskell-store/html/store.haddock
haddock-html: /usr/share/doc/haskell-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
